/* solaris.h

   Copyright (C) 2001, 2007 Free Software Foundation, Inc.

   Written by Marcus Brinkmann.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 3
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA 02110-1301 USA.
 */

#ifndef IFCONFIG_SYSTEM_SOLARIS_H
#define IFCONFIG_SYSTEM_SOLARIS_H

#include "../printif.h"
#include "../options.h"
#include <sys/sockio.h>



/* Option support.  */

struct system_ifconfig
{
  int valid;
};


/* Output format support.  */

#define SYSTEM_FORMAT_HANDLER \
  {"qnx", fh_nothing},

#endif
